@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2018-2022 Mike Fährmann
+# Copyright 2018-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,7 @@ class PiczelExtractor(Extractor):
     filename_fmt = "{category}_{id}_{title}_{num:>02}.{extension}"
     archive_fmt = "{id}_{num}"
     root = "https://piczel.tv"
-    api_root = "https://tombstone.piczel.tv"
+    root_api = root
 
     def items(self):
         for post in self.posts():
@@ -68,17 +68,14 @@ class PiczelUserExtractor(PiczelExtractor):
     """Extractor for all images from a user's gallery"""
     subcategory = "user"
     pattern = r"(?:https?://)?(?:www\.)?piczel\.tv/gallery/([^/?#]+)/?$"
-    test = ("https://piczel.tv/gallery/Bikupan", {
-        "range": "1-100",
-        "count": ">= 100",
-    })
+    example = "https://piczel.tv/gallery/USER"
 
     def __init__(self, match):
         PiczelExtractor.__init__(self, match)
         self.user = match.group(1)
 
     def posts(self):
-        url = "{}/api/users/{}/gallery".format(self.api_root, self.user)
+        url = "{}/api/users/{}/gallery".format(self.root_api, self.user)
         return self._pagination(url)
 
 
@@ -89,16 +86,14 @@ class PiczelFolderExtractor(PiczelExtractor):
     archive_fmt = "f{folder[id]}_{id}_{num}"
     pattern = (r"(?:https?://)?(?:www\.)?piczel\.tv"
                r"/gallery/(?!image)([^/?#]+)/(\d+)")
-    test = ("https://piczel.tv/gallery/Lulena/1114", {
-        "count": ">= 4",
-    })
+    example = "https://piczel.tv/gallery/USER/12345"
 
     def __init__(self, match):
         PiczelExtractor.__init__(self, match)
         self.user, self.folder_id = match.groups()
 
     def posts(self):
-        url = "{}/api/users/{}/gallery".format(self.api_root, self.user)
+        url = "{}/api/users/{}/gallery".format(self.root_api, self.user)
         return self._pagination(url, int(self.folder_id))
 
 
@@ -106,35 +101,12 @@ class PiczelImageExtractor(PiczelExtractor):
     """Extractor for individual images"""
     subcategory = "image"
     pattern = r"(?:https?://)?(?:www\.)?piczel\.tv/gallery/image/(\d+)"
-    test = ("https://piczel.tv/gallery/image/7807", {
-        "pattern": r"https://(\w+\.)?piczel\.tv/static/uploads/gallery_image"
-                   r"/32920/image/7807/1532236438-Lulena\.png",
-        "content": "df9a053a24234474a19bce2b7e27e0dec23bff87",
-        "keyword": {
-            "created_at": "2018-07-22T05:13:58.000Z",
-            "date": "dt:2018-07-22 05:13:58",
-            "description": None,
-            "extension": "png",
-            "favorites_count": int,
-            "folder_id": 1113,
-            "id": 7807,
-            "is_flash": False,
-            "is_video": False,
-            "multi": False,
-            "nsfw": False,
-            "num": 0,
-            "password_protected": False,
-            "tags": ["fanart", "commission", "altair", "recreators"],
-            "title": "Altair",
-            "user": dict,
-            "views": int,
-        },
-    })
+    example = "https://piczel.tv/gallery/image/12345"
 
     def __init__(self, match):
         PiczelExtractor.__init__(self, match)
         self.image_id = match.group(1)
 
     def posts(self):
-        url = "{}/api/gallery/{}".format(self.api_root, self.image_id)
+        url = "{}/api/gallery/{}".format(self.root_api, self.image_id)
         return (self.request(url).json(),)
